@@ -25,9 +25,12 @@ from scooby.knowledge import (  # noqa
 from scooby.report import Report, get_version
 from scooby.tracker import TrackedReport, track_imports, untrack_imports
 
+doo = Report
+
 __all__ = [
     'Report',
     'TrackedReport',
+    'doo',
     'get_standard_lib_modules',
     'in_ipython',
     'in_ipykernel',
@@ -40,4 +43,4 @@ __all__ = [
 __author__ = 'Dieter Werthmüller & Bane Sullivan'
 __license__ = 'MIT'
 __copyright__ = '2019, Dieter Werthmüller & Bane Sullivan'
-__version__ = '0.5.8'
+__version__ = '0.5.10'
