@@ -1,6 +1,5 @@
 """
-
-knowledge
+Knowledge
 =========
 
 The knowledge base.
@@ -14,6 +13,7 @@ as available RAM or MKL info.
 """
 import distutils.sysconfig as sysconfig
 import os
+from pathlib import Path
 import sys
 
 try:
@@ -23,6 +23,7 @@ except ImportError:
 
 try:
     import mkl
+
     mkl.get_version_string()
 except (ImportError, AttributeError):
     mkl = False
@@ -35,10 +36,23 @@ except ImportError:
 # Get available RAM, if available
 if psutil:
     tmem = psutil.virtual_memory().total
-    TOTAL_RAM = '{:.1f} GB'.format(tmem / (1024.0 ** 3))
+    TOTAL_RAM = '{:.1f} GiB'.format(tmem / (1024.0 ** 3))
 else:
     TOTAL_RAM = False
 
+# Get the type of the file system at the path of the scooby package
+if psutil:
+    # Code by https://stackoverflow.com/a/35291824/10504481
+    my_path = str(Path(__file__).resolve())
+    best_match = ""
+    FILESYSTEM_TYPE = ""
+    for part in psutil.disk_partitions():
+        if my_path.startswith(part.mountpoint) and len(best_match) < len(part.mountpoint):
+            FILESYSTEM_TYPE = part.fstype
+            best_match = part.mountpoint
+else:
+    FILESYSTEM_TYPE = False
+
 # Get mkl info from numexpr or mkl, if available
 if mkl:
     MKL_INFO = mkl.get_version_string()
@@ -59,6 +73,7 @@ VERSION_ATTRIBUTES = {
 def get_pyqt5_version():
     """Returns the PyQt5 version"""
     from PyQt5.Qt import PYQT_VERSION_STR
+
     return PYQT_VERSION_STR
 
 
@@ -124,8 +139,7 @@ def get_standard_lib_modules():
     else:
         names = os.listdir(sysconfig.get_python_lib(standard_lib=True))
 
-        stdlib_pkgs = set([name if not name.endswith(".py") else name[:-3]
-                           for name in names])
+        stdlib_pkgs = set([name if not name.endswith(".py") else name[:-3] for name in names])
 
     stdlib_pkgs = {
         "python",
@@ -145,7 +159,7 @@ def get_standard_lib_modules():
         "time",
         "unicodedata",
         "mmap",
-        }.union(stdlib_pkgs)
+    }.union(stdlib_pkgs)
     return stdlib_pkgs
 
 
@@ -166,8 +180,7 @@ def version_tuple(v):
         split_v.append('0')
 
     if len(split_v) > 3:
-        raise ValueError('Version strings containing more than three parts '
-                         'cannot be parsed')
+        raise ValueError('Version strings containing more than three parts ' 'cannot be parsed')
 
     vals = []
     for item in split_v:
